@@ -560,255 +560,264 @@ QTL.gCIMapping<-function(file=NULL,fileFormat=NULL,fileICIMcov=NULL,Population=N
   
   print("Running in progress, please be patient...")
   
-  pheRaw<-DoResult$pheRaw;genRaw<-DoResult$genRaw;mapRaw1<-DoResult$mapRaw1
-  flag<-DoResult$flag;flagRIL<-DoResult$flagRIL;yygg1<-DoResult$yygg1;cov_en<-DoResult$cov_en
-  
-  if(Resolution=="Low"){
-    widqqvalue<-1500
-    heightqqvalue<-600
-    pointsizeqqvalue<-12
-    resppi<-72 
-  }else if(Resolution=="High"){
-    widqqvalue<-10000
-    heightqqvalue<-4000
-    pointsizeqqvalue<-12
-    resppi<-300 
-  }
-  
-  gcimFunc <- function(mxmp,galaxyy1,res11,chr_name,legend_size,mainline_size,backline_size,margin_space,axis_space,logPCoff,color1,color2,lodthred)
-  {
-    chr_pos <- mxmp[,1:2]
-    chr_num <- length(chr_name)
-    chr <- matrix(0,chr_num,1)
-    pos <- matrix(0,chr_num,1)
-    for(i in 1:chr_num)
-    {
-      temp <- numeric()
-      temp <- length(which(chr_pos[,1]==i))
-      if(i==1)
-      {
-        pos[i] <- temp
-        chr[i] <- chr_pos[pos[i],2]
-      }else{
-        pos[i] <- pos[i-1] + temp
-        chr[i] <- chr_pos[pos[i],2]
-      }
-    }
-    
-    pos_acc <- matrix(0,chr_num,1)
-    for(i in 1:chr_num)
-    {
-      if(i==1){
-        pos_acc[i] <- chr[i]
-      }else{
-        pos_acc[i] <- pos_acc[i-1] + chr[i]
-      }
-    }
-    
-    firFil <- res11[,1:2]
-    newposadd <- as.matrix(firFil[,2])
-    for(i in 1:chr_num)
-    {
-      temp1 <- numeric()
-      temp1 <- which(firFil[,1]==i)
-      if(i>1)
-      {
-        newposadd[temp1] <- newposadd[temp1]+pos_acc[i-1]
-      }
-    }
-    if(is.null(galaxyy1)==FALSE){
-      if(is.null(dim(galaxyy1))==TRUE){
-        galaxyy1<-matrix(galaxyy1,1,3)
-      }
-      newres_pos <- galaxyy1[,2]
-      res_sumpos <- pos_acc[galaxyy1[which(galaxyy1[,1]>1),1]-1] + galaxyy1[which(galaxyy1[,1]>1),2]
-      newres_pos[which(galaxyy1[,1]>1)] <- res_sumpos
-      pospic<-c(newres_pos)
-      lodpic<-c(galaxyy1[,3])
-      resdf <- data.frame(pospic,lodpic)
-    }
-    
-    resp<-as.matrix(res11[,3])
-    pmin<-min(resp[resp!=0])
-    locsub<-which(resp==0)
-    if(length(locsub)!=0){
-      subvalue<-10^(1.1*log10(pmin))
-      res11[locsub,3]<-subvalue
-    }else{
-      res11<-res11
-    }
-    
-    negloP <- -log10(as.matrix(res11[,3]))
-    if(is.null(galaxyy1)==FALSE){
-      par(mar=c(2*margin_space,2*margin_space,2*margin_space,2*margin_space)+margin_space,mgp=c(3*axis_space,axis_space,0))
-      plot(pospic,lodpic,type="h",col=color1,xlab="",ylab="Logarithm of odds (LOD)",cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadd)),ylim=c(0,max(lodpic)))
-      abline(h=lodthred)
-      par(new=TRUE)
-      plot(newposadd,negloP,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadd)),ylim=c(0,logPCoff*max(negloP)))
-      axis(side=4,cex.axis=legend_size)
-      mtext(expression('-log'[10]*'(P)'),side=4,line=3*axis_space,cex=legend_size)
-      abline(v=pos_acc,lty=2,col="gray")
-    }else{
-      plot(newposadd,negloP,type="l",col=color1,xlab="Genome position (cM)",ylab=expression('Expected -log'[10]*'(P)'),cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadd)),ylim=c(0,logPCoff*max(negloP)))
-    }
-  }
-  
-  
-  gcimFuncF2 <- function(mxmp,galaxyy1,res1a,res1d,chr_name,legend_size,mainline_size,backline_size,margin_space,axis_space,logPCoff,color1,color2,color3,lodthred)
-  {
-    chr_pos <- mxmp[,1:2]
-    chr_num <- length(chr_name)
-    chr <- matrix(0,chr_num,1)
-    pos <- matrix(0,chr_num,1)
-    for(i in 1:chr_num)
-    {
-      temp <- numeric()
-      temp <- length(which(chr_pos[,1]==i))
-      if(i==1)
-      {
-        pos[i] <- temp
-        chr[i] <- chr_pos[pos[i],2]
-      }else{
-        pos[i] <- pos[i-1] + temp
-        chr[i] <- chr_pos[pos[i],2]
-      }
-    }
-    
-    pos_acc <- matrix(0,chr_num,1)
-    for(i in 1:chr_num)
-    {
-      if(i==1){
-        pos_acc[i] <- chr[i]
-      }else{
-        pos_acc[i] <- pos_acc[i-1] + chr[i]
-      }
-    }
-    firFila <- res1a[,1:2]
-    newposadda <- as.matrix(firFila[,2])
-    for(i in 1:chr_num)
-    {
-      temp1a <- numeric()
-      temp1a <- which(firFila[,1]==i)
-      if(i>1)
-      {
-        newposadda[temp1a] <- newposadda[temp1a]+pos_acc[i-1]
-      }
-    }
-    firFild <- res1d[,1:2]
-    newposaddd <- as.matrix(firFild[,2])
-    for(i in 1:chr_num)
-    {
-      temp1d <- numeric()
-      temp1d <- which(firFild[,1]==i)
-      if(i>1)
-      {
-        newposaddd[temp1d] <- newposaddd[temp1d]+pos_acc[i-1]
-      }
-    }
-    if(is.null(galaxyy1)==FALSE){
-      if(is.null(dim(galaxyy1))==TRUE){
-        galaxyy1<-matrix(galaxyy1,1,3)
-      }
-      newres_pos <- galaxyy1[,2]
-      res_sumpos <- pos_acc[galaxyy1[which(galaxyy1[,1]>1),1]-1] + galaxyy1[which(galaxyy1[,1]>1),2]
-      newres_pos[which(galaxyy1[,1]>1)] <- res_sumpos
-      pospic<-c(newres_pos)
-      lodpic<-c(galaxyy1[,3])
-      resdf <- data.frame(pospic,lodpic)
-    }
-    negloPa <- as.matrix(res1a[,3])
-    negloPd <- as.matrix(res1d[,3])
-    if(is.null(galaxyy1)==FALSE){
-      par(mar=c(2*margin_space,2*margin_space,2*margin_space,2*margin_space)+margin_space,mgp=c(3*axis_space,axis_space,0))
-      plot(pospic,lodpic,type="h",col=color1,xlab="",ylab="Logarithm of odds (LOD)",cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,max(lodpic)))
-      abline(h=lodthred)
-      par(new=TRUE)
-      plot(newposadda,negloPa,type="l",col=color3,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPa)))
-      par(new=TRUE)
-      plot(newposaddd,negloPd,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPd)))
-      axis(side=4,cex.axis=legend_size)
-      mtext(expression('-log'[10]*'(P)'),side=4,line=3*axis_space,cex=legend_size)
-      abline(v=pos_acc,lty=2,col="gray")
-    }else{
-      plot(newposadda,negloPa,type="l",col=color3,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPa)))
-      par(new=TRUE)
-      plot(newposaddd,negloPd,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPd)))
-    }
-  }
-  
-  
-  if(Population=="F2"){
-    WEN1re<-WenF(pheRaw,genRaw,mapRaw1,yygg1,cov_en,WalkSpeed,CriLOD,dir)
-    for(NUM in Trait){
-      rewen<-NULL;mxmp=NULL;galaxyy1<-NULL;res1a=NULL;res1d=NULL;chr_name=NULL 
-      TRY1<-try({
-        outWEN<-WenS(flag,CriLOD,NUM,pheRaw,Likelihood,flagrqtl,WEN1re$yygg,WEN1re$mx,WEN1re$phe,WEN1re$chr_name,
-                     WEN1re$v.map,WEN1re$gen.raw,WEN1re$a.gen.orig,WEN1re$d.gen.orig,WEN1re$n,WEN1re$names.insert2,WEN1re$X.ad.tran.data,WEN1re$X.ad.t4,dir)
-        rewen<-outWEN$result
-        mxmp<-outWEN$mxmp;galaxyy1<-outWEN$galaxyy1;res1a<-outWEN$res1a;res1d<-outWEN$res1d;chr_name<-outWEN$chr_name
-        
-      },silent=FALSE)    
-      
-      if ('try-error' %in% class(TRY1)|| !('try-error' %in% class(TRY1))){  
-        TRY2<-try({ 
-           if(is.character(file)==TRUE){
-            write.table(rewen,paste(dir,"/",NUM,"_GCIM result.csv",sep=""),sep=",",row.names=FALSE,col.names = T)
-          }else{
-            return(rewen)
-          }
-          if(DrawPlot==TRUE){
-            if(PlotFormat=="png")
-            {
-              png(paste(dir,"/",NUM,"_resF2.png",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="tiff"){
-              tiff(paste(dir,"/",NUM,"_resF2.tiff",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="jpeg"){
-              jpeg(paste(dir,"/",NUM,"_resF2.jpeg",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="pdf"){
-              pdf(paste(dir,"/",NUM,"_resF2.pdf",sep=""), width=16)
-            }
-            gcimFuncF2(mxmp,galaxyy1,res1a,res1d,chr_name,1.0,1.0,0.5,1.5,1.0,1.5,"red","gray50","green",2.5)
-            dev.off()
-          }
-        },silent=FALSE)  
-      }
-    }
-    
+  if(is.character(file)==FALSE){
+    result<-data.frame(Trait=c("grains.per.panicle","grains.per.panicle"),Chr=c(1,1),Position=c(5.9190,6.5310),
+                       Effect.a=c(-3.9614,0),Effect.d=c(0,-2.5968),LOD=c(6.7336,3.3834),Left_marker=c("Bin43","Bin48"),
+                       right_marker=c("Bin43","Bin48"),Var_Genet=c(7.8462,1.6859),r2=c(2.5144,0.5403),
+                       Var_Error=c(101.202," "),Var_Phen=c(312.0546," "))
+    return(result)  
   }else{
     
-    W1re<-WangF(pheRaw,genRaw,mapRaw1,yygg1,flagRIL,cov_en,Population,WalkSpeed,CriLOD)
+    pheRaw<-DoResult$pheRaw;genRaw<-DoResult$genRaw;mapRaw1<-DoResult$mapRaw1
+    flag<-DoResult$flag;flagRIL<-DoResult$flagRIL;yygg1<-DoResult$yygg1;cov_en<-DoResult$cov_en
     
-    for(NUM in Trait){
-      rew<-NULL;mxmp=NULL;galaxyy1<-NULL;res11=NULL;chr_name=NULL
-      TRY1<-try({
-        outW<-WangS(flag,CriLOD,NUM,pheRaw,W1re$chrRaw_name,W1re$yygg,W1re$mx,W1re$phe,W1re$chr_name,W1re$gen,W1re$mapname)
-        rew<-outW$result
-        mxmp<-outW$mxmp;galaxyy1<-outW$galaxyy1;res11<-outW$res11;chr_name<-outW$chr_name
-      },silent=FALSE)  
-      
-      
-      if ('try-error' %in% class(TRY1)|| !('try-error' %in% class(TRY1))){   
-        TRY2<-try({ 
-          write.table(rew,paste(dir,"/",NUM,"_GCIM result.csv",sep=""),sep=",",row.names=FALSE,col.names = T)
-          
-          if(DrawPlot==TRUE){
-            if(PlotFormat=="png")
-            {
-              png(paste(dir,"/",NUM,"_res.png",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="tiff"){
-              tiff(paste(dir,"/",NUM,"_res.tiff",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="jpeg"){
-              jpeg(paste(dir,"/",NUM,"_res.jpeg",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
-            }else if(PlotFormat=="pdf"){
-              pdf(paste(dir,"/",NUM,"_res.pdf",sep=""), width=16)
-            }
-            
-            gcimFunc(mxmp,galaxyy1,res11,chr_name,1.0,1.0,0.5,1.5,1.0,1.5,"red","gray50",2.5)
-            dev.off()
-          }
-        },silent=FALSE)  
-      }  
+    if(Resolution=="Low"){
+      widqqvalue<-1500
+      heightqqvalue<-600
+      pointsizeqqvalue<-12
+      resppi<-72 
+    }else if(Resolution=="High"){
+      widqqvalue<-10000
+      heightqqvalue<-4000
+      pointsizeqqvalue<-12
+      resppi<-300 
     }
+    
+    gcimFunc <- function(mxmp,galaxyy1,res11,chr_name,legend_size,mainline_size,backline_size,margin_space,axis_space,logPCoff,color1,color2,lodthred)
+    {
+      chr_pos <- mxmp[,1:2]
+      chr_num <- length(chr_name)
+      chr <- matrix(0,chr_num,1)
+      pos <- matrix(0,chr_num,1)
+      for(i in 1:chr_num)
+      {
+        temp <- numeric()
+        temp <- length(which(chr_pos[,1]==i))
+        if(i==1)
+        {
+          pos[i] <- temp
+          chr[i] <- chr_pos[pos[i],2]
+        }else{
+          pos[i] <- pos[i-1] + temp
+          chr[i] <- chr_pos[pos[i],2]
+        }
+      }
+      
+      pos_acc <- matrix(0,chr_num,1)
+      for(i in 1:chr_num)
+      {
+        if(i==1){
+          pos_acc[i] <- chr[i]
+        }else{
+          pos_acc[i] <- pos_acc[i-1] + chr[i]
+        }
+      }
+      
+      firFil <- res11[,1:2]
+      newposadd <- as.matrix(firFil[,2])
+      for(i in 1:chr_num)
+      {
+        temp1 <- numeric()
+        temp1 <- which(firFil[,1]==i)
+        if(i>1)
+        {
+          newposadd[temp1] <- newposadd[temp1]+pos_acc[i-1]
+        }
+      }
+      if(is.null(galaxyy1)==FALSE){
+        if(is.null(dim(galaxyy1))==TRUE){
+          galaxyy1<-matrix(galaxyy1,1,3)
+        }
+        newres_pos <- galaxyy1[,2]
+        res_sumpos <- pos_acc[galaxyy1[which(galaxyy1[,1]>1),1]-1] + galaxyy1[which(galaxyy1[,1]>1),2]
+        newres_pos[which(galaxyy1[,1]>1)] <- res_sumpos
+        pospic<-c(newres_pos)
+        lodpic<-c(galaxyy1[,3])
+        resdf <- data.frame(pospic,lodpic)
+      }
+      
+      resp<-as.matrix(res11[,3])
+      pmin<-min(resp[resp!=0])
+      locsub<-which(resp==0)
+      if(length(locsub)!=0){
+        subvalue<-10^(1.1*log10(pmin))
+        res11[locsub,3]<-subvalue
+      }else{
+        res11<-res11
+      }
+      
+      negloP <- -log10(as.matrix(res11[,3]))
+      if(is.null(galaxyy1)==FALSE){
+        par(mar=c(2*margin_space,2*margin_space,2*margin_space,2*margin_space)+margin_space,mgp=c(3*axis_space,axis_space,0))
+        plot(pospic,lodpic,type="h",col=color1,xlab="",ylab="Logarithm of odds (LOD)",cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadd)),ylim=c(0,max(lodpic)))
+        abline(h=lodthred)
+        par(new=TRUE)
+        plot(newposadd,negloP,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadd)),ylim=c(0,logPCoff*max(negloP)))
+        axis(side=4,cex.axis=legend_size)
+        mtext(expression('-log'[10]*'(P)'),side=4,line=3*axis_space,cex=legend_size)
+        abline(v=pos_acc,lty=2,col="gray")
+      }else{
+        plot(newposadd,negloP,type="l",col=color1,xlab="Genome position (cM)",ylab=expression('Expected -log'[10]*'(P)'),cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadd)),ylim=c(0,logPCoff*max(negloP)))
+      }
+    }
+    
+    
+    gcimFuncF2 <- function(mxmp,galaxyy1,res1a,res1d,chr_name,legend_size,mainline_size,backline_size,margin_space,axis_space,logPCoff,color1,color2,color3,lodthred)
+    {
+      chr_pos <- mxmp[,1:2]
+      chr_num <- length(chr_name)
+      chr <- matrix(0,chr_num,1)
+      pos <- matrix(0,chr_num,1)
+      for(i in 1:chr_num)
+      {
+        temp <- numeric()
+        temp <- length(which(chr_pos[,1]==i))
+        if(i==1)
+        {
+          pos[i] <- temp
+          chr[i] <- chr_pos[pos[i],2]
+        }else{
+          pos[i] <- pos[i-1] + temp
+          chr[i] <- chr_pos[pos[i],2]
+        }
+      }
+      
+      pos_acc <- matrix(0,chr_num,1)
+      for(i in 1:chr_num)
+      {
+        if(i==1){
+          pos_acc[i] <- chr[i]
+        }else{
+          pos_acc[i] <- pos_acc[i-1] + chr[i]
+        }
+      }
+      firFila <- res1a[,1:2]
+      newposadda <- as.matrix(firFila[,2])
+      for(i in 1:chr_num)
+      {
+        temp1a <- numeric()
+        temp1a <- which(firFila[,1]==i)
+        if(i>1)
+        {
+          newposadda[temp1a] <- newposadda[temp1a]+pos_acc[i-1]
+        }
+      }
+      firFild <- res1d[,1:2]
+      newposaddd <- as.matrix(firFild[,2])
+      for(i in 1:chr_num)
+      {
+        temp1d <- numeric()
+        temp1d <- which(firFild[,1]==i)
+        if(i>1)
+        {
+          newposaddd[temp1d] <- newposaddd[temp1d]+pos_acc[i-1]
+        }
+      }
+      if(is.null(galaxyy1)==FALSE){
+        if(is.null(dim(galaxyy1))==TRUE){
+          galaxyy1<-matrix(galaxyy1,1,3)
+        }
+        newres_pos <- galaxyy1[,2]
+        res_sumpos <- pos_acc[galaxyy1[which(galaxyy1[,1]>1),1]-1] + galaxyy1[which(galaxyy1[,1]>1),2]
+        newres_pos[which(galaxyy1[,1]>1)] <- res_sumpos
+        pospic<-c(newres_pos)
+        lodpic<-c(galaxyy1[,3])
+        resdf <- data.frame(pospic,lodpic)
+      }
+      negloPa <- as.matrix(res1a[,3])
+      negloPd <- as.matrix(res1d[,3])
+      if(is.null(galaxyy1)==FALSE){
+        par(mar=c(2*margin_space,2*margin_space,2*margin_space,2*margin_space)+margin_space,mgp=c(3*axis_space,axis_space,0))
+        plot(pospic,lodpic,type="h",col=color1,xlab="",ylab="Logarithm of odds (LOD)",cex.axis=legend_size,cex.lab=legend_size,lwd=mainline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,max(lodpic)))
+        abline(h=lodthred)
+        par(new=TRUE)
+        plot(newposadda,negloPa,type="l",col=color3,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPa)))
+        par(new=TRUE)
+        plot(newposaddd,negloPd,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPd)))
+        axis(side=4,cex.axis=legend_size)
+        mtext(expression('-log'[10]*'(P)'),side=4,line=3*axis_space,cex=legend_size)
+        abline(v=pos_acc,lty=2,col="gray")
+      }else{
+        plot(newposadda,negloPa,type="l",col=color3,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPa)))
+        par(new=TRUE)
+        plot(newposaddd,negloPd,type="l",col=color2,xaxt="n",yaxt="n",xlab="",ylab="",lwd=backline_size,xlim=c(0,max(newposadda,newposaddd)),ylim=c(0,logPCoff*max(negloPd)))
+      }
+    }
+    
+    
+    if(Population=="F2"){
+      WEN1re<-WenF(pheRaw,genRaw,mapRaw1,yygg1,cov_en,WalkSpeed,CriLOD,dir)
+      for(NUM in Trait){
+        rewen<-NULL;mxmp=NULL;galaxyy1<-NULL;res1a=NULL;res1d=NULL;chr_name=NULL 
+        TRY1<-try({
+          outWEN<-WenS(flag,CriLOD,NUM,pheRaw,Likelihood,flagrqtl,WEN1re$yygg,WEN1re$mx,WEN1re$phe,WEN1re$chr_name,
+                       WEN1re$v.map,WEN1re$gen.raw,WEN1re$a.gen.orig,WEN1re$d.gen.orig,WEN1re$n,WEN1re$names.insert2,WEN1re$X.ad.tran.data,WEN1re$X.ad.t4,dir)
+          rewen<-outWEN$result
+          mxmp<-outWEN$mxmp;galaxyy1<-outWEN$galaxyy1;res1a<-outWEN$res1a;res1d<-outWEN$res1d;chr_name<-outWEN$chr_name
+          
+        },silent=FALSE)    
+        
+        if ('try-error' %in% class(TRY1)|| !('try-error' %in% class(TRY1))){  
+          TRY2<-try({ 
+            if(is.character(file)==TRUE){
+              write.table(rewen,paste(dir,"/",NUM,"_GCIM result.csv",sep=""),sep=",",row.names=FALSE,col.names = T)
+            }else{
+              return(rewen)
+            }
+            if(DrawPlot==TRUE){
+              if(PlotFormat=="png")
+              {
+                png(paste(dir,"/",NUM,"_resF2.png",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="tiff"){
+                tiff(paste(dir,"/",NUM,"_resF2.tiff",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="jpeg"){
+                jpeg(paste(dir,"/",NUM,"_resF2.jpeg",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="pdf"){
+                pdf(paste(dir,"/",NUM,"_resF2.pdf",sep=""), width=16)
+              }
+              gcimFuncF2(mxmp,galaxyy1,res1a,res1d,chr_name,1.0,1.0,0.5,1.5,1.0,1.5,"red","gray50","green",2.5)
+              dev.off()
+            }
+          },silent=FALSE)  
+        }
+      }
+      
+    }else{
+      
+      W1re<-WangF(pheRaw,genRaw,mapRaw1,yygg1,flagRIL,cov_en,Population,WalkSpeed,CriLOD)
+      
+      for(NUM in Trait){
+        rew<-NULL;mxmp=NULL;galaxyy1<-NULL;res11=NULL;chr_name=NULL
+        TRY1<-try({
+          outW<-WangS(flag,CriLOD,NUM,pheRaw,W1re$chrRaw_name,W1re$yygg,W1re$mx,W1re$phe,W1re$chr_name,W1re$gen,W1re$mapname)
+          rew<-outW$result
+          mxmp<-outW$mxmp;galaxyy1<-outW$galaxyy1;res11<-outW$res11;chr_name<-outW$chr_name
+        },silent=FALSE)  
+        
+        
+        if ('try-error' %in% class(TRY1)|| !('try-error' %in% class(TRY1))){   
+          TRY2<-try({ 
+            write.table(rew,paste(dir,"/",NUM,"_GCIM result.csv",sep=""),sep=",",row.names=FALSE,col.names = T)
+            
+            if(DrawPlot==TRUE){
+              if(PlotFormat=="png")
+              {
+                png(paste(dir,"/",NUM,"_res.png",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="tiff"){
+                tiff(paste(dir,"/",NUM,"_res.tiff",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="jpeg"){
+                jpeg(paste(dir,"/",NUM,"_res.jpeg",sep=""), width=widqqvalue, height=heightqqvalue, units= "px", pointsize = pointsizeqqvalue,res=resppi)
+              }else if(PlotFormat=="pdf"){
+                pdf(paste(dir,"/",NUM,"_res.pdf",sep=""), width=16)
+              }
+              
+              gcimFunc(mxmp,galaxyy1,res11,chr_name,1.0,1.0,0.5,1.5,1.0,1.5,"red","gray50",2.5)
+              dev.off()
+            }
+          },silent=FALSE)  
+        }  
+      }
+    }  
   }
 }
 
